@@ -1,5 +1,5 @@
 from client import *
 
 def connect(*args, **kwargs):
-    """connect(host, port=None, username=None, password=None)"""
+    """connect(host, port=0, auth=None, username=None, password=None, protocol='http')"""
     return Client(*args, **kwargs)
