@@ -51,7 +51,7 @@ class OperationFailed(WebdavException):
         operation_name = self._OPERATIONS[method]
         self.reason = 'Failed to {operation_name} "{path}"'.format(**locals())
         expected_codes = (expected_code,) if isinstance(expected_code, Number) else expected_code
-        expected_codes_str = ", ".join('{} {}'.format(code, codestr(code)) for code in expected_codes)
+        expected_codes_str = ", ".join('{0} {1}'.format(code, codestr(code)) for code in expected_codes)
         actual_code_str = codestr(actual_code)
         msg = '''\
 {self.reason}.
@@ -61,14 +61,16 @@ class OperationFailed(WebdavException):
         super(OperationFailed, self).__init__(msg)
 
 class Client(object):
-    def __init__(self, host, port=0, username=None, password=None,
+    def __init__(self, host, port=0, auth=None, username=None, password=None,
                  protocol='http'):
         if not port:
             port = 443 if protocol == 'https' else 80
-        self.baseurl = '{}://{}:{}'.format(protocol, host ,port)
+        self.baseurl = '{0}://{1}:{2}'.format(protocol, host ,port)
         self.cwd = '/'
         self.session = requests.session()
-        if username and password:
+        if auth:
+            self.session.auth = auth
+        elif username and password:
             self.session.auth = (username, password)
     def _send(self, method, path, expected_code, **kwargs):
         url = self._get_url(path)
@@ -123,7 +125,7 @@ class Client(object):
         with open(local_path, 'wb') as f:
             #f.write(response.content)
             shutil.copyfileobj(response.raw, f)
-    def ls(self, remote_path):
+    def ls(self, remote_path='.'):
         headers = {'Depth': '1'}
         response = self._send('PROPFIND', remote_path, (207, 301), headers=headers)
 
